@@ -12,11 +12,6 @@ from statsmodels.api import tsa
 # An unofficial google trends API
 from pytrends.request import TrendReq
 
-# This is for docstrings and representations of the indices
-from io import StringIO
-from pandas._config import get_option
-from pandas.io.formats import console
-
 class Trendex:
     """
     This class makes an index utilizing Google Trends from keywords.
@@ -171,35 +166,7 @@ class Trendex:
                 'Run make_index() to get result'
             return result
 
-
-        # Otherwise return a string representation for indices attribute.
-        df = self.gti
-        buf = StringIO("")
-        if df._info_repr():
-            df.info(buf=buf)
-            return buf.getvalue()
-
-        max_rows = get_option("display.max_rows")
-        min_rows = get_option("display.min_rows")
-        max_cols = get_option("display.max_columns")
-        max_colwidth = get_option("display.max_colwidth")
-        show_dimensions = get_option("display.show_dimensions")
-        if get_option("display.expand_frame_repr"):
-            width, _ = console.get_console_size()
-        else:
-            width = None
-        df.to_string(
-            buf=buf,
-            max_rows=max_rows,
-            min_rows=min_rows,
-            max_cols=max_cols,
-            line_width=width,
-            max_colwidth=max_colwidth,
-            show_dimensions=show_dimensions,
-        )
-
-        return '\n'.join(['The Calculated Index (stored in object.gti):'
-                          ,buf.getvalue()])
+        return 'An instantiation of WBTrends Class. Index is self.gti'
 
     def make_index(self,plot=True):
         """
@@ -315,7 +282,7 @@ class Trendex:
         elif self.seasonal and self.sa_method == 'index':
             indices = self.normalize(self.sadjust(trends.sum(axis=1)))
             indices.name = 'GTI'
-        elif self.season and self.sa_method == 'both':
+        elif self.seasonal and self.sa_method == 'both':
             indices = self.normalize(self.sadjust(trends_sa.sum(axis=1)))
             indices.name = 'GTI'
         else:
